pub struct EncryptionConstraint {
pub required_targets: Vec<String>,
pub backend: Option<String>,
pub mode: Option<EncryptionMode>,
}Expand description
Encryption constraint applied to files from a config source.
Fields
required_targets: Vec<String>Glob patterns or explicit paths that must be encrypted.
backend: Option<String>If set, restrict which backend is acceptable.
mode: Option<EncryptionMode>If set, restrict which encryption mode is acceptable.