pub struct ReconcilePatch {
pub kind: ReconcilePatchKind,
pub name: Option<String>,
pub interval: Option<String>,
pub auto_apply: Option<bool>,
pub drift_policy: Option<DriftPolicy>,
}Expand description
A kustomize-style reconcile patch targeting a specific module or profile.
When name is omitted, the patch applies to all entities of the given kind.
Fields
kind: ReconcilePatchKindname: Option<String>interval: Option<String>auto_apply: Option<bool>drift_policy: Option<DriftPolicy>Trait Implementations
Sourceimpl Clone for ReconcilePatch
impl Clone for ReconcilePatch
Sourcefn clone(&self) -> ReconcilePatch
fn clone(&self) -> ReconcilePatch
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ReconcilePatch
impl Debug for ReconcilePatch
Sourceimpl<'de> Deserialize<'de> for ReconcilePatch
impl<'de> Deserialize<'de> for ReconcilePatch
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more