http_agent

Function http_agent 

pub fn http_agent(timeout: Duration) -> Agent
Build a ureq::Agent with timeout applied. Exists so every call site that wants a timeout can use one line and we can change AgentBuilder configuration (user-agent defaults, connection pooling, TLS options) in exactly one place if it becomes necessary.