load_locked_modules

Function load_locked_modules 

pub fn load_locked_modules(
    config_dir: &Path,
    cache_base: &Path,
    modules: &mut HashMap<String, LoadedModule>,
    printer: &Printer,
) -> Result<()>
Load remote modules from the lockfile, fetching if needed, and merge them into the given modules map.