pub fn load_lockfile(config_dir: &Path) -> Result<ModuleLockfile>Expand description
Load the module lockfile from <config_dir>/modules.lock.
Returns an empty lockfile if the file does not exist.
pub fn load_lockfile(config_dir: &Path) -> Result<ModuleLockfile>Load the module lockfile from <config_dir>/modules.lock.
Returns an empty lockfile if the file does not exist.