pub fn command_output_with_timeout(
cmd: &mut Command,
timeout: Duration,
) -> Result<Output>Expand description
Run a [Command] with a timeout, killing the process if it exceeds the limit.
Returns Err if spawn fails or the process is killed due to timeout.